<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_AR" sourcelanguage="en" version="2.1">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/qtwrapper/callmanager_wrap.h" line="393"/>
        <source>Me</source>
        <translation>Yo</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="61"/>
        <source>Hold</source>
        <translation>Espera</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="63"/>
        <source>Talking</source>
        <translation>Hablando</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="65"/>
        <source>ERROR</source>
        <translation>ERROR</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="67"/>
        <source>Incoming</source>
        <translation>Entrante</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="69"/>
        <source>Calling</source>
        <translation>Llamando</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="71"/>
        <location filename="../src/chatview.cpp" line="72"/>
        <source>Connecting</source>
        <translation>Conectando</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="73"/>
        <source>Searching</source>
        <translation>Buscando</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="75"/>
        <source>Inactive</source>
        <translation>Inactivo</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="77"/>
        <location filename="../src/api/call.h" line="83"/>
        <location filename="../src/chatview.cpp" line="79"/>
        <source>Finished</source>
        <translation>Finalizado</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="79"/>
        <source>Timeout</source>
        <translation>Expiró el tiempo de espera</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="81"/>
        <source>Peer busy</source>
        <translation>Par ocupado</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="85"/>
        <source>Communication established</source>
        <translation>Comunicación establecida</translation>
    </message>
    <message>
        <location filename="../src/api/interaction.h" line="218"/>
        <location filename="../src/authority/storagehelper.cpp" line="136"/>
        <location filename="../src/authority/storagehelper.cpp" line="954"/>
        <source>Invitation received</source>
        <translation>Invitación recibida</translation>
    </message>
    <message>
        <location filename="../src/api/interaction.h" line="222"/>
        <source>Contact left conversation</source>
        <translation>El contacto abandonó la conversación</translation>
    </message>
    <message>
        <location filename="../src/api/interaction.h" line="216"/>
        <location filename="../src/authority/storagehelper.cpp" line="133"/>
        <location filename="../src/authority/storagehelper.cpp" line="952"/>
        <source>Contact added</source>
        <translation>Contacto añadido</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="110"/>
        <location filename="../src/authority/storagehelper.cpp" line="116"/>
        <location filename="../src/authority/storagehelper.cpp" line="950"/>
        <source>Outgoing call</source>
        <translation>Llamada saliente</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="112"/>
        <location filename="../src/authority/storagehelper.cpp" line="122"/>
        <source>Incoming call</source>
        <translation>Llamada entrante</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="118"/>
        <location filename="../src/authority/storagehelper.cpp" line="948"/>
        <source>Missed outgoing call</source>
        <translation>Llamada saliente perdida</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="124"/>
        <source>Missed incoming call</source>
        <translation>Llamada entrante perdida</translation>
    </message>
    <message>
        <location filename="../src/api/interaction.h" line="220"/>
        <location filename="../src/authority/storagehelper.cpp" line="138"/>
        <location filename="../src/authority/storagehelper.cpp" line="956"/>
        <source>Invitation accepted</source>
        <translation>Invitación aceptada</translation>
    </message>
    <message>
        <location filename="../src/avmodel.cpp" line="339"/>
        <location filename="../src/avmodel.cpp" line="358"/>
        <source>default</source>
        <translation>Por defecto</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="55"/>
        <source>Null</source>
        <translation>Inválido</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="56"/>
        <source>Trying</source>
        <translation>Intentando</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="57"/>
        <source>Ringing</source>
        <translation>Sonando</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="58"/>
        <source>Being Forwarded</source>
        <translation>Derivando llamada</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="59"/>
        <source>Queued</source>
        <translation>Llamada en espera</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="60"/>
        <source>Progress</source>
        <translation>Progreso</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="61"/>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="73"/>
        <location filename="../src/newcallmodel.cpp" line="62"/>
        <source>Accepted</source>
        <translation>Aceptada</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="63"/>
        <source>Multiple Choices</source>
        <translation>Múltiples elecciones</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="64"/>
        <source>Moved Permanently</source>
        <translation>Movido definitivamente</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="65"/>
        <source>Moved Temporarily</source>
        <translation>Movido temporalmente</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="66"/>
        <source>Use Proxy</source>
        <translation>Usar proxy</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="67"/>
        <source>Alternative Service</source>
        <translation>Servicio alternativo</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="68"/>
        <source>Bad Request</source>
        <translation>Solicitud incorrecta</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="69"/>
        <source>Unauthorized</source>
        <translation>No autorizado</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="70"/>
        <source>Payment Required</source>
        <translation>Pago requerido</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="71"/>
        <source>Forbidden</source>
        <translation>Denegado</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="72"/>
        <source>Not Found</source>
        <translation>No encontrado</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="73"/>
        <source>Method Not Allowed</source>
        <translation>Método no permitido</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="74"/>
        <location filename="../src/newcallmodel.cpp" line="94"/>
        <source>Not Acceptable</source>
        <translation>No aceptable</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="75"/>
        <source>Proxy Authentication Required</source>
        <translation>Se requiere autenticación del proxy</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="76"/>
        <source>Request Timeout</source>
        <translation>Tiempo de espera caducado</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="77"/>
        <source>Gone</source>
        <translation>Retirado</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="78"/>
        <source>Request Entity Too Large</source>
        <translation>Entidad solicitada demasiado grande</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="79"/>
        <source>Request URI Too Long</source>
        <translation>URI solicitada demasiado extensa</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="80"/>
        <source>Unsupported Media Type</source>
        <translation>Tipo de medio no soportado</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="81"/>
        <source>Unsupported URI Scheme</source>
        <translation>Esquema URI no soportado</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="82"/>
        <source>Bad Extension</source>
        <translation>Extensión errónea</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="83"/>
        <source>Extension Required</source>
        <translation>Extensión requerida</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="84"/>
        <source>Session Timer Too Small</source>
        <translation>Temporizador de sesión demasiado bajo</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="85"/>
        <source>Interval Too Brief</source>
        <translation>Intervalo demasiado breve</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="86"/>
        <source>Temporarily Unavailable</source>
        <translation>Temporalmente no disponible</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="87"/>
        <source>Call TSX Does Not Exist</source>
        <translation>Llamada TSX inexistente</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="88"/>
        <source>Loop Detected</source>
        <translation>Bucle detectado</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="89"/>
        <source>Too Many Hops</source>
        <translation>Demasiados saltos</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="90"/>
        <source>Address Incomplete</source>
        <translation>Dirección incompleta</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="91"/>
        <source>Ambiguous</source>
        <translation>Ambiguo</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="92"/>
        <source>Busy</source>
        <translation>Ocupado</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="93"/>
        <source>Request Terminated</source>
        <translation>Solicitud terminada</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="95"/>
        <source>Bad Event</source>
        <translation>Evento erróneo</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="96"/>
        <source>Request Updated</source>
        <translation>Solicitud actualizada</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="97"/>
        <source>Request Pending</source>
        <translation>Solicitud pendiente</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="98"/>
        <source>Undecipherable</source>
        <translation>Indescifrable</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="99"/>
        <source>Internal Server Error</source>
        <translation>Error de servidor interno</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="100"/>
        <source>Not Implemented</source>
        <translation>No implementado</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="101"/>
        <source>Bad Gateway</source>
        <translation>Puerta de salida errónea</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="102"/>
        <source>Service Unavailable</source>
        <translation>Servicio no disponible</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="103"/>
        <source>Server Timeout</source>
        <translation>Tiempo de espera del servidor agotado</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="104"/>
        <source>Version Not Supported</source>
        <translation>Versión no soportada</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="105"/>
        <source>Message Too Large</source>
        <translation>Mensaje demasiado extenso</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="106"/>
        <source>Precondition Failure</source>
        <translation>Falla de precondición</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="107"/>
        <source>Busy Everywhere</source>
        <translation>Ocupado en todas partes</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="108"/>
        <source>Call Refused</source>
        <translation>Llamada rechazada</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="109"/>
        <source>Does Not Exist Anywhere</source>
        <translation>No existe en ningún lado</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="110"/>
        <source>Not Acceptable Anywhere</source>
        <translation>No aceptable en ningún lado</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="30"/>
        <source>Hide chat view</source>
        <translation>Ocultar vista de conversación</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="31"/>
        <source>Place video call</source>
        <translation>Realizar videollamada</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="32"/>
        <source>Show available plugins</source>
        <translation>Mostrar complementos disponibles</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="33"/>
        <source>Place audio call</source>
        <translation>Realizar audiollamada</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="34"/>
        <source>Add to conversations</source>
        <translation>Agregar a conversaciones</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="35"/>
        <source>Unban contact</source>
        <translation>Desbloquear contacto</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="36"/>
        <source>Send</source>
        <translation>Enviar</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="37"/>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="38"/>
        <source>Jump to latest</source>
        <translation>Ir a lo último</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="39"/>
        <source>Send file</source>
        <translation>Enviar archivo</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="40"/>
        <source>Add emoji</source>
        <translation>Añadir emoji</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="41"/>
        <source>Leave video message</source>
        <translation>Dejar mensaje de video</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="42"/>
        <source>Leave audio message</source>
        <translation>Dejar mensaje de audio</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="44"/>
        <source>Copy to downloads</source>
        <translation>Copiar a descargas</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="45"/>
        <source>Write to {0}</source>
        <translation>Escribir a {0}</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="50"/>
        <source>has sent you a conversation request.</source>
        <translation>te ha enviado una solicitud de conversación.</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="52"/>
        <source>Hello, do you want to join the conversation?</source>
        <translation>Hola, ¿querés unirte a la conversación?</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="54"/>
        <source>You have accepted the conversation request.</source>
        <translation>Has aceptado la solicitud de conversación.</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="56"/>
        <source>We are waiting for another device to synchronize the conversation.</source>
        <translation>Esperando a otro dispositivo para sincronizar la conversación.</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="67"/>
        <source>Accept</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="68"/>
        <source>Refuse</source>
        <translation>Rechazar</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="71"/>
        <source>Unable to make contact</source>
        <translation>No se pudo contactar</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="76"/>
        <source>Waiting for contact</source>
        <translation>Esperando al contacto</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="77"/>
        <source>Incoming transfer</source>
        <translation>Transferencia entrante</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="78"/>
        <source>Timed out waiting for contact</source>
        <translation>Expiró el tiempo de espera al contacto</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="43"/>
        <source>Block</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="47"/>
        <source>Note: an interaction will create a new contact.</source>
        <translation>Nota: una interacción creará un nuevo contacto.</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="48"/>
        <source>is not in your contacts</source>
        <translation>no está en tus contactos</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="58"/>
        <source>Note: you can automatically accept this invitation by sending a message.</source>
        <translation>Nota: podés aceptar automáticamente esta invitación enviando un mensaje.</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="59"/>
        <source>{0} days ago</source>
        <translation>Hace {0} días</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="60"/>
        <source>{0} hours ago</source>
        <translation>Hace {0} horas</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="62"/>
        <source>{0} minutes ago</source>
        <translation>Hace {0} minutos</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="74"/>
        <source>Canceled</source>
        <translation>Cancelado</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="75"/>
        <source>Ongoing</source>
        <translation>En curso</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="59"/>
        <source>%d days ago</source>
        <translation>hace %d días</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="60"/>
        <source>%d hours ago</source>
        <translation>hace %d horas</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="62"/>
        <source>%d minutes ago</source>
        <translation>hace %d minutos</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="63"/>
        <source>one day ago</source>
        <translation>hace un día</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="64"/>
        <source>one hour ago</source>
        <translation>hace una hora</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="65"/>
        <source>just now</source>
        <translation>hace un momento</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="66"/>
        <source>Failure</source>
        <translation>Falla</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="69"/>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="70"/>
        <source>Retry</source>
        <translation>Reintentar</translation>
    </message>
</context>
<context>
    <name>lrc::ContactModelPimpl</name>
    <message>
        <location filename="../src/contactmodel.cpp" line="474"/>
        <source>Searching…</source>
        <translation>Buscando...</translation>
    </message>
    <message>
        <location filename="../src/contactmodel.cpp" line="999"/>
        <source>Invalid ID</source>
        <translation>ID inválido</translation>
    </message>
    <message>
        <location filename="../src/contactmodel.cpp" line="1002"/>
        <source>Username not found</source>
        <translation>Nombre de usuario no encontrado</translation>
    </message>
    <message>
        <location filename="../src/contactmodel.cpp" line="1005"/>
        <source>Couldn&apos;t lookup…</source>
        <translation>No se pudo buscar...</translation>
    </message>
</context>
<context>
    <name>lrc::api::ContactModel</name>
    <message>
        <location filename="../src/contactmodel.cpp" line="435"/>
        <source>Bad URI scheme</source>
        <translation>Esquema URI erróneo</translation>
    </message>
</context>
</TS>